@@ -84,21 +84,21 @@ this.dfield = NaN;
 if (colPt >= this.columnDecoders.length) System.out.println("???");
 if (this.columnDecoders[colPt] == null) {
 this.fieldIsValid = false;
-return this.fieldStr = this.nullString;
+return this.fieldStr = JU.CifDataParser.nullString;
 }switch (this.columnDecoders[colPt].dataType) {
 case 1:
 this.ifield = this.columnDecoders[colPt].getIntValue(this.rowPt);
-this.fieldStr = (this.ifield == -2147483648 ? this.nullString : "_");
+this.fieldStr = (this.ifield == -2147483648 ? JU.CifDataParser.nullString : "_");
 break;
 case 2:
 this.dfield = this.columnDecoders[colPt].getFixedPtValue(this.rowPt);
-this.fieldStr = (Double.isNaN(this.dfield) ? this.nullString : "_");
+this.fieldStr = (Double.isNaN(this.dfield) ? JU.CifDataParser.nullString : "_");
 break;
 case 3:
 this.fieldStr = this.columnDecoders[colPt].getStringValue(this.rowPt);
 break;
 }
-this.fieldIsValid = (this.fieldStr !== this.nullString);
+this.fieldIsValid = (this.fieldStr !== JU.CifDataParser.nullString);
 return this.fieldStr;
 }, "~N");
 Clazz.defineMethod(c$, "isFieldValid", 
@@ -135,4 +135,4 @@ throw e;
 }
 }, "~A");
 });
-;//5.0.1-v7 Mon May 12 17:22:27 CDT 2025
+;//5.0.1-v7 Mon May 19 16:00:40 CDT 2025
