@@ -96,8 +96,8 @@ function(){
 this.ich++;
 var cterm0 = this.cterm;
 this.cterm = '}';
-var ns = this.nullString;
-this.nullString = null;
+var ns = JU.CifDataParser.nullString;
+JU.CifDataParser.nullString = null;
 var map = (this.asObject ?  new java.util.Hashtable() : null);
 var n = 0;
 var str = "";
@@ -113,7 +113,7 @@ if (n++ > 0) str += ",";
 str += key + " : " + this.getNextToken();
 }}
 this.cterm = cterm0;
-this.nullString = ns;
+JU.CifDataParser.nullString = ns;
 return (this.asObject ? map : "{" + str + "}");
 });
 Clazz.defineMethod(c$, "isSpaceOrColon", 
@@ -191,4 +191,4 @@ for (var i = 0; i < n; i++) a[i] = Clazz.floatToInt(f[i]);
 return a;
 }, "~S,~N");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Sun May 18 17:28:13 CDT 2025
