@@ -6,4 +6,4 @@ function(){
 return  new J.adapter.readers.cif.Cif2DataParser().set(this, null, this.debugging);
 });
 });
-;//5.0.1-v7 Mon May 12 17:22:27 CDT 2025
+;//5.0.1-v7 Sun May 18 17:28:13 CDT 2025
