@@ -16,6 +16,7 @@ this.thisChain = -1;
 this.modelIndex = 0;
 this.chainSum = null;
 this.chainAtomCount = null;
+this.carbohydrateGroups = null;
 this.isLigandBondBug = false;
 this.mident = null;
 this.requiresSorting = false;
@@ -347,18 +348,23 @@ function(){
 this.parseLoopParameters(J.adapter.readers.cif.MMCifReader.chemCompFields);
 var groupName;
 var hetName;
-while (this.cifParser.getData()) if (!this.isNull(groupName = this.getFieldString(0)) && !this.isNull(hetName = this.getFieldString(1))) this.addHetero(groupName, hetName, true, true);
+var groupType;
+while (this.cifParser.getData()) if (!this.isNull(groupName = this.getFieldString(0)) && !this.isNull(hetName = this.getFieldString(1)) && !this.isNull(groupType = this.getFieldString(2))) this.addHetero(groupName, hetName, groupType, true, true);
 
 return true;
 });
 Clazz.defineMethod(c$, "addHetero", 
-function(groupName, hetName, doCheck, addNote){
+function(groupName, hetName, groupType, doCheck, addNote){
 if (doCheck && !this.vwr.getJBR().isHetero(groupName)) return;
 if (this.htHetero == null) this.htHetero =  new java.util.Hashtable();
 if (doCheck && this.htHetero.containsKey(groupName)) return;
 this.htHetero.put(groupName, hetName);
 if (addNote) this.appendLoadNote(groupName + " = " + hetName);
-}, "~S,~S,~B,~B");
+if (groupType != null && groupType.indexOf("accharide") >= 0) {
+if (this.carbohydrateGroups == null) this.carbohydrateGroups = "";
+this.carbohydrateGroups += "[" + groupName + "]";
+}if (addNote) this.appendLoadNote(groupName + " = " + hetName);
+}, "~S,~S,~S,~B,~B");
 Clazz.defineMethod(c$, "processStructConfLoopBlock", 
 function(){
 if (this.ignoreStructure) {
@@ -535,8 +541,8 @@ if (!sym1.equals(sym2) || !this.isNull(sym1) && !sym1.equals("1_555")) continue;
 var type = this.getFieldString(12);
 if (!type.startsWith("covale") && !type.equals("disulf") && !type.equals("metalc")) continue;
 if (this.htBondMap == null) this.htBondMap =  new java.util.Hashtable();
-var key1 = this.vwr.getChainID(this.getFieldString(0), true) + this.getFieldString(2) + this.parseIntFieldTok(1) + this.getFieldString(3) + this.getFieldString(4);
-var key2 = this.vwr.getChainID(this.getFieldString(6), true) + this.getFieldString(8) + this.parseIntFieldTok(7) + this.getFieldString(9) + this.getFieldString(10);
+var key1 = "" + this.vwr.getChainID(this.getFieldString(0), true) + this.getFieldString(2) + this.parseIntFieldTok(1) + this.getFieldString(3) + this.getFieldString(4);
+var key2 = "" + this.vwr.getChainID(this.getFieldString(6), true) + this.getFieldString(8) + this.parseIntFieldTok(7) + this.getFieldString(9) + this.getFieldString(10);
 var order = this.getBondOrder(this.getFieldString(13));
 if (this.structConnMap == null) this.structConnMap =  new JU.Lst();
 this.structConnMap.addLast( Clazz.newArray(-1, [key1, key2, Integer.$valueOf(order)]));
@@ -638,16 +644,19 @@ function(){
 if (this.htHetero != null) {
 this.asc.setCurrentModelInfo("hetNames", this.htHetero);
 this.asc.setInfo("hetNames", this.htHetero);
-}});
+if (this.carbohydrateGroups != null) {
+this.asc.setInfo("carbohydrates", this.carbohydrateGroups);
+this.asc.setCurrentModelInfo("carbohydrates", this.carbohydrateGroups);
+}}});
 c$.ncsoperFields =  Clazz.newArray(-1, ["*_matrix[1][1]", "*_matrix[1][2]", "*_matrix[1][3]", "*_vector[1]", "*_matrix[2][1]", "*_matrix[2][2]", "*_matrix[2][3]", "*_vector[2]", "*_matrix[3][1]", "*_matrix[3][2]", "*_matrix[3][3]", "*_vector[3]", "*_id", "*_symmetry_operation"]);
 c$.operFields =  Clazz.newArray(-1, ["*_matrix[1][1]", "*_matrix[1][2]", "*_matrix[1][3]", "*_vector[1]", "*_matrix[2][1]", "*_matrix[2][2]", "*_matrix[2][3]", "*_vector[2]", "*_matrix[3][1]", "*_matrix[3][2]", "*_matrix[3][3]", "*_vector[3]", "*_id", "*_symmetry_operation"]);
 c$.assemblyFields =  Clazz.newArray(-1, ["_pdbx_struct_assembly_gen_assembly_id", "_pdbx_struct_assembly_gen_oper_expression", "_pdbx_struct_assembly_gen_asym_id_list"]);
 c$.structRefFields =  Clazz.newArray(-1, ["_struct_ref_seq_dif_mon_id", "_struct_ref_seq_dif_db_mon_id"]);
-c$.chemCompFields =  Clazz.newArray(-1, ["_chem_comp_id", "_chem_comp_name"]);
+c$.chemCompFields =  Clazz.newArray(-1, ["_chem_comp_id", "_chem_comp_name", "_chem_comp_type"]);
 c$.structConfFields =  Clazz.newArray(-1, ["*_conf_type_id", "*_beg_auth_asym_id", "*_beg_auth_seq_id", "*_pdbx_beg_pdb_ins_code", "*_end_auth_asym_id", "*_end_auth_seq_id", "*_pdbx_end_pdb_ins_code", "*_id", "*_pdbx_pdb_helix_id", "*_pdbx_pdb_helix_class"]);
 c$.structSheetRangeFields =  Clazz.newArray(-1, ["*_sheet_id", "*_beg_auth_asym_id", "*_beg_auth_seq_id", "*_pdbx_beg_pdb_ins_code", "*_end_auth_asym_id", "*_end_auth_seq_id", "*_pdbx_end_pdb_ins_code", "*_id"]);
 c$.structSiteFields =  Clazz.newArray(-1, ["*_site_id", "*_auth_comp_id", "*_auth_asym_id", "*_auth_seq_id", "*_pdbx_auth_ins_code"]);
 c$.structConnFields =  Clazz.newArray(-1, ["*_ptnr1_auth_asym_id", "*_ptnr1_auth_seq_id", "*_ptnr1_auth_comp_id", "*_ptnr1_label_atom_id", "*_pdbx_ptnr1_label_alt_id", "*_ptnr1_symmetry", "*_ptnr2_auth_asym_id", "*_ptnr2_auth_seq_id", "*_ptnr2_auth_comp_id", "*_ptnr2_label_atom_id", "*_pdbx_ptnr2_label_alt_id", "*_ptnr2_symmetry", "*_conn_type_id", "*_pdbx_value_order"]);
 c$.chemCompBondFields =  Clazz.newArray(-1, ["*_comp_id", "*_atom_id_1", "*_atom_id_2", "*_value_order", "*_pdbx_aromatic_flag"]);
 });
-;//5.0.1-v7 Mon May 12 17:22:27 CDT 2025
+;//5.0.1-v7 Mon May 19 16:01:22 CDT 2025
