@@ -133,17 +133,20 @@ seqNo = groupIdList[j];
 var group3 = g.get("groupName");
 var isHetero = this.vwr.getJBR().isHetero(group3);
 if (isHetero) {
-var hetName = "" + g.get("chemCompType");
+var groupType = "" + g.get("chemCompType");
 if (this.htHetero == null || !this.htHetero.containsKey(group3)) {
-if (this.entities != null && hetName.equals("NON-POLYMER")) out : for (var i = this.entities.length; --i >= 0; ) {
+var hetName = groupType;
+if (this.entities != null && hetName.equals("NON-POLYMER")) {
+out : for (var i = this.entities.length; --i >= 0; ) {
 var entity = this.entities[i];
 var chainList = entity.get("chainIndexList");
-for (var k = chainList.length; --k >= 0; ) if (chainList[k] == iChain) {
+for (var k = chainList.length; --k >= 0; ) {
+if (chainList[k] == iChain) {
 hetName = "a component of the entity \"" + entity.get("description") + "\"";
 break out;
+}}
 }
-}
-this.addHetero(group3, hetName, false, true);
+}this.addHetero(group3, hetName, groupType.toLowerCase(), false, true);
 }}var elementList = g.get("elementList");
 var haveAtom = false;
 for (var ia = 0, pt = 0; ia < len; ia++, iatom++) {
@@ -286,4 +289,4 @@ function(key){
 return JU.MessagePackReader.decode(this.map.get(key));
 }, "~S");
 });
-;//5.0.1-v7 Mon May 12 17:22:27 CDT 2025
+;//5.0.1-v7 Mon May 19 16:00:40 CDT 2025
