@@ -132,7 +132,7 @@ throw e;
 if (this.userData == null) return;
 for (var key, $key = this.userData.keySet().iterator (); $key.hasNext()&& ((key = $key.next ()) || true);) {
 var a = this.userData.get(key);
-var f =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.QualifiedName*/a.length, 0);
+var f =  Clazz.newFloatArray (a.length, 0);
 for (var i = 0; i < a.length; i++) f[i] = (a[i] == null ? 0 : this.mr.parseFloatStr(a[i]));
 
 this.mr.asc.setAtomProperties(key, f, -1, false);
@@ -172,4 +172,4 @@ this.line = this.line.substring(0, this.line.length - 1) + this.rd().substring(7
 return this.line;
 });
 });
-;//5.0.1-v4 Wed Dec 11 08:23:48 CST 2024
+;//5.0.1-v7 Mon May 12 16:54:26 CDT 2025
