@@ -78,4 +78,4 @@ this.asc.addVibrationVector(atom.index, vx, vy, vz);
 }
 }, "~N");
 });
-;//5.0.1-v2 Fri Jun 07 15:32:46 BST 2024
+;//5.0.1-v7 Mon May 12 16:54:26 CDT 2025
