@@ -81,4 +81,4 @@ this.asc.setCurrentModelInfo("jmolDataProperties", this.props);
 this.finalizeReaderPDB();
 });
 });
-;//5.0.1-v7 Mon May 12 17:14:01 CDT 2025
+;//5.0.1-v7 Sun May 18 17:40:18 CDT 2025
