@@ -13,4 +13,4 @@ atom.partialCharge = this.parseFloatStr(tokens[pt++]);
 atom.radius = J.adapter.readers.pdb.PdbReader.fixRadius(this.parseFloatStr(tokens[pt]));
 }}, "J.adapter.smarter.Atom");
 });
-;//5.0.1-v7 Wed Apr 02 04:50:42 CDT 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
