@@ -1291,4 +1291,4 @@ this.jmolToUniqueID =  Clazz.newIntArray (nAtomsJmol, 0);
 }, "~N");
 c$.MEAS_DIGITS =  Clazz.newIntArray(-1, [530, 531, 532]);
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
