@@ -406,4 +406,4 @@ for (var i = 0; i < this.modelAtomCount; i++) this.setAtomCoordScaled(atoms[i +
 
 }, "~S,~B,~B");
 });
-;//5.0.1-v7 Wed Apr 02 04:50:42 CDT 2025
+;//5.0.1-v7 Mon May 12 16:54:26 CDT 2025
