@@ -186,4 +186,4 @@ c$.$DC_LIST = "xx    yy    zz    xy    xz    yz";
 c$.$FS_LIST = "NOT IMPLEMENTED IN THIS READER";
 c$.$FC_LIST = "xxx   yyy   zzz   yyx   xxy   xxz   zzx   zzy   yyz   xyz";
 });
-;//5.0.1-v7 Thu Apr 10 21:51:05 CDT 2025
+;//5.0.1-v7 Mon May 12 16:54:26 CDT 2025
