@@ -63,7 +63,7 @@ haveAtomTypes = (n > 0);
 checking = false;
 } else {
 var count = htBondCounts.get(t);
-if (count == null) htBondCounts.put(t, count =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/1, 0));
+if (count == null) htBondCounts.put(t, count =  Clazz.newIntArray (1, 0));
 if (++count[0] > 10) haveAtomTypes = !(checking = false);
 }}}
 }
@@ -100,4 +100,4 @@ n = (J.adapter.smarter.Atom.isValidSym2(c1, c2) || c1 == 'C' && c2 == 'L' ? 2 :
 return name.substring(0, n);
 }, "~S");
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Mon May 12 16:54:26 CDT 2025
