@@ -69,4 +69,4 @@ if (!ignore[j]) this.asc.addVibrationVector(i + (lineBaseFreqCount + j) * ac, x,
 }
 });
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Mon May 12 16:54:26 CDT 2025
