@@ -179,4 +179,4 @@ function(value){
 this.asc.setAtomSetName(this.constraints + (this.constraints.length == 0 ? "" : " ") + "Energy=" + value + " KJ");
 }, "~N");
 });
-;//5.0.1-v2 Fri Jun 07 15:32:46 BST 2024
+;//5.0.1-v7 Mon May 12 16:54:26 CDT 2025
