@@ -603,4 +603,4 @@ bs.andNot(this.deleteAtoms);
 }});
 c$.unitCellParamTags =  Clazz.newArray(-1, ["a", "b", "c", "alpha", "beta", "gamma"]);
 });
-;//5.0.1-v7 Thu Apr 10 21:51:05 CDT 2025
+;//5.0.1-v7 Mon May 12 16:54:26 CDT 2025
