@@ -123,7 +123,7 @@ this.beta = (Math.acos(va.dot(vc)) * 180 / 3.141592653589793);
 this.gamma = (Math.acos(va.dot(vb)) * 180 / 3.141592653589793);
 } else if ("positions".equals(this.name)) {
 this.parent.setUnitCell(this.a, this.b, this.c, this.alpha, this.beta, this.gamma);
-var fdata =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.InfixExpression*/this.ac * 3, 0);
+var fdata =  Clazz.newFloatArray (this.ac * 3, 0);
 J.adapter.smarter.AtomSetCollectionReader.getTokensFloat(this.data.toString(), fdata, this.ac * 3);
 var fpt = 0;
 for (var i = 0; i < this.ac; i++) {
@@ -133,7 +133,7 @@ atom.elementSymbol = this.atomSyms[i];
 atom.atomName = this.atomNames[i];
 }
 } else if ("forces".equals(this.name)) {
-var fdata =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.InfixExpression*/this.ac * 3, 0);
+var fdata =  Clazz.newFloatArray (this.ac * 3, 0);
 J.adapter.smarter.AtomSetCollectionReader.getTokensFloat(this.data.toString(), fdata, this.ac * 3);
 var fpt = 0;
 var i0 = this.asc.getLastAtomSetAtomIndex();
@@ -156,4 +156,4 @@ break;
 this.setKeepChars(false);
 }, "~S");
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Mon May 12 16:54:26 CDT 2025
