@@ -564,4 +564,4 @@ v.z = (cosph * data[6] - sinph * data[7]);
 c$.lengthUnitIds =  Clazz.newArray(-1, ["bohr", "m", "cm", "nm", "ang", "a0"]);
 c$.lengthUnitFactors =  Clazz.newFloatArray(-1, [0.5291772, 1E10, 1E8, 1E1, 1.0, 0.5291772]);
 });
-;//5.0.1-v7 Mon May 12 17:14:01 CDT 2025
+;//5.0.1-v7 Sun May 18 17:40:18 CDT 2025
