@@ -809,4 +809,4 @@ return false;
 c$.crtypes =  Clazz.newArray(-1, ["??", "nuclei", "bonds", "rings", "cages"]);
 c$.smap =  Clazz.newIntArray(-1, [2, 3, 4, 11, 5, 6, 7, 12, 8, 9, 10, 13]);
 });
-;//5.0.1-v7 Mon May 12 17:14:01 CDT 2025
+;//5.0.1-v7 Sun May 18 17:40:18 CDT 2025
