@@ -211,4 +211,4 @@ if (!this.haveMagnetic && this.asc.ac > 0) {
 this.setProperties("pwm_magnetic",  Clazz.newFloatArray (this.asc.ac, 0), this.nAtoms);
 }});
 });
-;//5.0.1-v7 Wed Apr 02 04:50:42 CDT 2025
+;//5.0.1-v7 Mon May 12 16:54:26 CDT 2025
