@@ -233,4 +233,4 @@ this.asc.xtalSymmetry.setPartProperty();
 });
 c$.supportedRecordTypes =  Clazz.newArray(-1, ["TITL", "CELL", "SPGR", "SFAC", "LATT", "SYMM", "NOTE", "ATOM", "PART", "END"]);
 });
-;//5.0.1-v7 Mon May 12 17:14:01 CDT 2025
+;//5.0.1-v7 Sun May 18 17:40:18 CDT 2025
