@@ -34,13 +34,13 @@ Clazz.overrideMethod(c$, "getEncodedOrder",
 function(){
 return this.bond.order;
 });
-Clazz.overrideMethod(c$, "getRadius", 
+Clazz.overrideMethod(c$, "getPymolRadius", 
 function(){
-return this.bond.radius;
+return this.bond.pymolRadius;
 });
 Clazz.overrideMethod(c$, "getColix", 
 function(){
 return this.bond.colix;
 });
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Mon May 12 16:54:26 CDT 2025
