@@ -1075,7 +1075,6 @@ this.spinFrameExt = null;
 this.spinFramePp = null;
 this.spinFrameXyz = null;
 this.perpUVW = null;
-this.spinFrameAxisType = null;
 this.spinFrameRotationMatrix = null;
 this.nSpins = 0;
 Clazz.instantialize(this, arguments);}, J.adapter.smarter.XtalSymmetry, "FileSymmetry", JS.Symmetry);
@@ -1195,6 +1194,7 @@ inv.getRotationScale(rot);
 rot.rotate(this.perpUVW);
 this.toCartesian(this.perpUVW, true);
 this.spinFrameRotationMatrix = JU.Quat.newVA(this.perpUVW, 0).getMatrix();
+} else {
 }this.spinFrameXyz =  new JU.M4();
 var v =  new JU.P3();
 for (var i = 4; --i > 0; ) {
@@ -1220,10 +1220,10 @@ this.setUnitCellFromParams(unitCellParams, false, NaN);
 this.spinFramePp = this.convertTransform(this.spinFrame, null);
 this.spinFramePp =  new JU.M4();
 var spinABC = JS.UnitCell.getMatrixAndUnitCell(this.unitCell, this.spinFrame, this.spinFramePp);
-this.spinFrameAxisType = "axisxyz";
+var spinFrameAxisType = "axisxyz";
 var strAxis = this.getSpinExt(this.spinFrameExt, "axisxyz");
 if (strAxis == null) strAxis = this.getSpinExt(this.spinFrameExt, "axisxyz");
-if (strAxis == null) strAxis = this.getSpinExt(this.spinFrameExt, this.spinFrameAxisType = "perpuvw");
+if (strAxis == null) strAxis = this.getSpinExt(this.spinFrameExt, spinFrameAxisType = "perpuvw");
 if (strAxis != null) {
 var angle = JU.PT.parseFloat(this.getSpinExt(this.spinFrameExt, "angle"));
 if (!Float.isNaN(angle)) {
@@ -1234,7 +1234,7 @@ abc = this.getVariableAxis(strAxis);
 abc = this.getCif2Array(strAxis,  Clazz.newFloatArray (3, 0));
 }if (abc != null) {
 var axis = JU.V3.new3(abc[0], abc[1], abc[2]);
-if (this.spinFrameAxisType.equals("perpuvw")) {
+if (spinFrameAxisType.equals("perpuvw")) {
 this.perpUVW = axis;
 } else {
 this.spinFrameRotationMatrix =  new JU.M3().setAA(JU.A4.newVA(axis, (angle * (0.017453292519943295))));
@@ -1290,4 +1290,4 @@ return this.nSpins;
 }, "J.adapter.smarter.AtomSetCollection");
 /*eoif3*/})();
 });
-;//5.0.1-v7 Mon May 12 21:36:36 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
