@@ -1,3 +1,3 @@
 Clazz.declarePackage("J.api.js");
 Clazz.declareInterface(J.api.js, "JSmolAppletObject", javajs.api.js.JSAppletObject);
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
