@@ -195,7 +195,7 @@ var shortName = file.getName();
 this.outputMtl(" map_Kd " + shortName + "\n");
 this.outputMtl(" map_Ka " + shortName + "\n");
 }var matrix = JU.M4.newM4(null);
-matrix.setTranslation(JU.V3.newV(meshSurface.offset));
+if (meshSurface.offset != null) matrix.setTranslation(JU.V3.newV(meshSurface.offset));
 var bsValid =  new JU.BS();
 this.addMesh(name, data, matrix, null, colix, dim, bsValid);
 }, "JU.MeshSurface,~N");
@@ -405,7 +405,7 @@ this.output("vt 0.0 0.0\n");
 this.output("vt " + width + " " + height + "\n");
 }}this.output("# Number of faces: " + nFaces + "\n");
 for (var i = 0; i < nFaces; i++) if (dim != null) this.outputFace2(faces[i], i, map, map2);
- else this.outputFace1(faces[i], map, map2);
+ else this.outputFace1(faces[i], map, map2, normals != null);
 
 if (dim != null) this.currentTextureOrigin += nFaces;
 this.currentVertexOrigin += nVertices;
@@ -421,12 +421,12 @@ this.output(prefix + this.ptTemp.x + " " + this.ptTemp.y + " " + this.ptTemp.z +
 }
 }, "~A,~N,JU.M4,~S,JU.BS");
 Clazz.defineMethod(c$, "outputFace1", 
-function(face, map, map2){
+function(face, map, map2, withNormals){
 this.output("f");
-for (var i, $i = 0, $$i = face; $i < $$i.length && ((i = $$i[$i]) || true); $i++) this.output(" " + ((map == null ? i : map[i]) + this.currentVertexOrigin) + "//" + ((map2 == null ? i : map2[i]) + this.currentNormalOrigin));
+for (var i, $i = 0, $$i = face; $i < $$i.length && ((i = $$i[$i]) || true); $i++) this.output(" " + ((map == null ? i : map[i]) + this.currentVertexOrigin) + (withNormals ? "//" + ((map2 == null ? i : map2[i]) + this.currentNormalOrigin) : ""));
 
 this.output("\n");
-}, "~A,~A,~A");
+}, "~A,~A,~A,~B");
 Clazz.defineMethod(c$, "outputFace2", 
 function(face, vt, map, map2){
 this.output("f");
@@ -500,4 +500,4 @@ throw ex;
 }
 }, "~S,JU.MeshSurface,~A");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
