@@ -242,4 +242,4 @@ if (!this.haveMacros) this.writeMacros2();
 this.output("r(" + this.getTriad(ptA) + "," + this.getTriad(ptB) + "," + this.getTriad(ptC) + "," + this.color4(colix) + ")\n");
 }, "JU.T3,JU.T3,JU.T3,~N");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
