@@ -136,4 +136,4 @@ if (radius < 1) radius = 1;
 this.outputEllipsoid(center, radius, coef, colix);
 }, "JU.P3,~A,~N,~N,~N,~N,~N,JU.M3,~A,JU.M4,~A");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
