@@ -600,4 +600,4 @@ this.argbEndcap = shadesEndcap[this.endcapShadeIndex];
 this.endCapHidden = (this.endcaps == 1);
 }, "~B,~B");
 });
-;//5.0.1-v7 Wed Apr 02 04:50:42 CDT 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
