@@ -385,4 +385,4 @@ return s;
 }, "java.io.File");
 c$.inchiVersionInternal = null;
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
