@@ -180,4 +180,4 @@ $.getScript(J2S.inchiPath +   "/inchi-web-SwingJS.js");
 }} catch (t) {
 }
 }});
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
