@@ -412,8 +412,8 @@ var vertexCount = this.jvxlData.vertexCount = this.meshData.vc;
 var colixes = this.meshData.vcs;
 var vertexValues = this.meshData.vvs;
 if ("none".equals(this.jvxlColorEncodingRead)) {
-this.jvxlData.vertexColors =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/vertexCount, 0);
-var nextc =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/1, 0);
+this.jvxlData.vertexColors =  Clazz.newIntArray (vertexCount, 0);
+var nextc =  Clazz.newIntArray (1, 0);
 var n = JU.PT.parseIntNext(this.jvxlColorDataRead, nextc);
 n = Math.min(n, vertexCount);
 var tokens = JU.PT.getTokens(this.jvxlColorDataRead.substring(nextc[0]));
@@ -447,7 +447,7 @@ var getValues = (Float.isNaN(this.valueMin));
 if (getValues) this.setValueMinMax();
 var contourPlaneMinimumValue = 3.4028235E38;
 var contourPlaneMaximumValue = -3.4028235E38;
-if (colixes == null || colixes.length < vertexCount) this.meshData.vcs = colixes =  Clazz.newShortArray (/*org.eclipse.jdt.core.dom.SimpleName*/vertexCount, 0);
+if (colixes == null || colixes.length < vertexCount) this.meshData.vcs = colixes =  Clazz.newShortArray (vertexCount, 0);
 var colixNeg = 0;
 var colixPos = 0;
 if (this.params.colorBySign) {
@@ -571,15 +571,15 @@ Clazz.defineMethod(c$, "jvxlDecodeTriangleData",
 function(tdata, edgeData, colorData){
 var nTriangles = this.parseIntStr(J.jvxl.readers.XmlReader.getXmlAttrib(tdata, "count"));
 if (nTriangles < 0) return;
-var nextc =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/1, 0);
+var nextc =  Clazz.newIntArray (1, 0);
 var nColors = (colorData == null ? -1 : 1);
 var color = 0;
 JU.Logger.info("Reading " + nTriangles + " triangles");
 var encoding = J.jvxl.readers.JvxlXmlReader.getEncoding(tdata);
 tdata = this.getData(tdata, "jvxlTriangleData");
 var edata = this.getData(edgeData, "jvxlTriangleEdgeData");
-var vertex =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
-var nextp =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/1, 0);
+var vertex =  Clazz.newIntArray (3, 0);
+var nextp =  Clazz.newIntArray (1, 0);
 var nexte = null;
 var edgeMask = 7;
 var haveEdgeInfo;
@@ -592,7 +592,7 @@ haveEdgeInfo = (edata.length == nTriangles);
 var n = JU.PT.parseIntNext(tdata, nextp);
 haveEdgeInfo = (edata.length > 0);
 if (haveEdgeInfo) {
-nexte =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/1, 0);
+nexte =  Clazz.newIntArray (1, 0);
 JU.PT.parseIntNext(edata, nexte);
 } else if (n > 0) {
 JU.Logger.info("JvxlXmlReader: jvxlTriangleEdgeData count=" + n + "; expected " + nTriangles);
@@ -673,8 +673,8 @@ vs.addLast(v);
 var n = vs.size();
 if (n > 0) {
 jvxlData.vContours = JU.AU.createArrayOfArrayList(n);
-jvxlData.contourColixes = this.params.contourColixes =  Clazz.newShortArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
-jvxlData.contourValues = this.params.contoursDiscrete =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
+jvxlData.contourColixes = this.params.contourColixes =  Clazz.newShortArray (n, 0);
+jvxlData.contourValues = this.params.contoursDiscrete =  Clazz.newFloatArray (n, 0);
 for (var i = 0; i < n; i++) {
 jvxlData.vContours[i] = vs.get(i);
 jvxlData.contourValues[i] = (jvxlData.vContours[i].get(2)).floatValue();
@@ -697,4 +697,4 @@ this.meshData =  new J.jvxl.data.MeshData();
 }this.updateTriangles();
 }});
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
