@@ -38,7 +38,7 @@ this.isSquaredLinear = false;
 Clazz.instantialize(this, arguments);}, J.quantum, "MOCalculation", J.quantum.QuantumCalculation);
 Clazz.prepareFields (c$, function(){
 this.dataAdders =  new Array(20);
-this.dataAdderOK =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/20, 0);
+this.dataAdderOK =  Clazz.newIntArray (20, 0);
 });
 Clazz.makeConstructor(c$, 
 function(){
@@ -57,7 +57,7 @@ this.firstAtomOffset = firstAtomOffset;
 this.shells = shells;
 this.gaussians = gaussians;
 this.dfCoefMaps = (dfCoefMaps == null ? J.quantum.QS.getNewDfCoefMap() : dfCoefMaps);
-this.coeffs =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.FieldAccess*/this.dfCoefMaps[this.dfCoefMaps.length - 1].length, 0);
+this.coeffs =  Clazz.newDoubleArray (this.dfCoefMaps[this.dfCoefMaps.length - 1].length, 0);
 this.slaters = slaters;
 this.moCoefficients = moCoefficients;
 this.linearCombination = linearCombination;
@@ -68,7 +68,7 @@ if (doNormalize) this.setNormalization(moData.get("nboType"));
 this.countsXYZ = volumeData.getVoxelCounts();
 this.initialize(this.countsXYZ[0], this.countsXYZ[1], this.countsXYZ[2], points);
 this.voxelData = volumeData.getVoxelData();
-this.voxelDataTemp = (isSquaredLinear ?  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nX, /*org.eclipse.jdt.core.dom.SimpleName*/this.nY, /*org.eclipse.jdt.core.dom.SimpleName*/this.nZ, 0) : this.voxelData);
+this.voxelDataTemp = (isSquaredLinear ?  Clazz.newFloatArray (this.nX, this.nY, this.nZ, 0) : this.voxelData);
 this.setupCoordinates(volumeData.getOriginFloat(), volumeData.getVolumetricVectorLengths(), bsSelected, xyz, atoms, points, false);
 this.doDebug = (JU.Logger.debugging);
 return !bsSelected.isEmpty() && (slaters != null || this.checkCalculationType());
@@ -89,15 +89,15 @@ JU.Logger.info("Normalization of contractions (NWCHEM)");
 Clazz.overrideMethod(c$, "initialize", 
 function(nX, nY, nZ, points){
 this.initialize0(nX, nY, nZ, points);
-this.CX =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.FieldAccess*/this.nX, 0);
-this.CY =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.FieldAccess*/this.nY, 0);
-this.CZ =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.FieldAccess*/this.nZ, 0);
-this.DXY =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.FieldAccess*/this.nX, 0);
-this.DXZ =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.FieldAccess*/this.nX, 0);
-this.DYZ =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.FieldAccess*/this.nY, 0);
-this.EX =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.FieldAccess*/this.nX, 0);
-this.EY =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.FieldAccess*/this.nY, 0);
-this.EZ =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.FieldAccess*/this.nZ, 0);
+this.CX =  Clazz.newDoubleArray (this.nX, 0);
+this.CY =  Clazz.newDoubleArray (this.nY, 0);
+this.CZ =  Clazz.newDoubleArray (this.nZ, 0);
+this.DXY =  Clazz.newDoubleArray (this.nX, 0);
+this.DXZ =  Clazz.newDoubleArray (this.nX, 0);
+this.DYZ =  Clazz.newDoubleArray (this.nY, 0);
+this.EX =  Clazz.newDoubleArray (this.nX, 0);
+this.EY =  Clazz.newDoubleArray (this.nY, 0);
+this.EZ =  Clazz.newDoubleArray (this.nZ, 0);
 }, "~N,~N,~N,~A");
 Clazz.overrideMethod(c$, "createCube", 
 function(){
@@ -761,4 +761,4 @@ JU.Logger.info("Integrated density = " + this.integration + " for volume " + (vo
 });
 c$.shellOrder =  Clazz.newArray(-1, [ Clazz.newArray(-1, ["S"]),  Clazz.newArray(-1, ["X", "Y", "Z"]),  Clazz.newArray(-1, ["S", "X", "Y", "Z"]),  Clazz.newArray(-1, ["d0/z2", "d1+/xz", "d1-/yz", "d2+/x2-y2", "d2-/xy"]),  Clazz.newArray(-1, ["XX", "YY", "ZZ", "XY", "XZ", "YZ"]),  Clazz.newArray(-1, ["f0/2z3-3x2z-3y2z", "f1+/4xz2-x3-xy2", "f1-/4yz2-x2y-y3", "f2+/x2z-y2z", "f2-/xyz", "f3+/x3-3xy2", "f3-/3x2y-y3"]),  Clazz.newArray(-1, ["XXX", "YYY", "ZZZ", "XYY", "XXY", "XXZ", "XZZ", "YZZ", "YYZ", "XYZ"])]);
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
