@@ -647,4 +647,4 @@ c$.nf = java.text.NumberFormat.getInstance();
 J.quantum.NMRNoeMatrix.nf.setMinimumFractionDigits(4);
 J.quantum.NMRNoeMatrix.nf.setMaximumFractionDigits(4);
 }});
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
