@@ -40,7 +40,7 @@ this.p1 = null;
 this.p2 = null;
 Clazz.instantialize(this, arguments);}, J.quantum, "NciCalculation", J.quantum.QuantumPlaneCalculation);
 Clazz.prepareFields (c$, function(){
-this.eigenValues =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
+this.eigenValues =  Clazz.newFloatArray (3, 0);
 this.yzPlanesRho = JU.AU.newFloat2(2);
 });
 Clazz.makeConstructor(c$, 
@@ -103,7 +103,7 @@ this.xMin = this.yMin = this.zMin = 0;
 this.xMax = this.yMax = this.zMax = points.length;
 }this.setupCoordinates(volumeData.getOriginFloat(), volumeData.getVolumetricVectorLengths(), bsSelected, atomCoordAngstroms, null, points, true);
 if (this.qmAtoms != null) {
-var qmMap =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.MethodInvocation*/bsSelected.length(), 0);
+var qmMap =  Clazz.newIntArray (bsSelected.length(), 0);
 for (var i = this.qmAtoms.length; --i >= 0; ) {
 qmMap[this.qmAtoms[i].index] = i;
 if (this.qmAtoms[i].znuc < 1) {
@@ -123,7 +123,7 @@ for (var j = bs.nextSetBit(0); j >= 0; j = bs.nextSetBit(j + 1)) this.qmAtoms[qm
 this.nMolecules++;
 JU.Logger.info("Molecule " + (this.nMolecules) + " (" + bs.cardinality() + " atoms): " + JU.Escape.eBS(bs));
 }
-this.rhoMolecules =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nMolecules, 0);
+this.rhoMolecules =  Clazz.newDoubleArray (this.nMolecules, 0);
 }if (this.nMolecules == 0) this.nMolecules = 1;
 if (this.nMolecules == 1) {
 this.noValuesAtAll = (this.type != 0 && this.type != 1);
@@ -165,7 +165,7 @@ this.initializeOnePointQC();
 Clazz.defineMethod(c$, "initializeEigen", 
 function(){
 this.eigen =  new JU.Eigen().set(3);
-this.hess =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, /*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
+this.hess =  Clazz.newDoubleArray (3, 3, 0);
 });
 Clazz.overrideMethod(c$, "getPlane", 
 function(ix, yzPlane){
@@ -367,4 +367,4 @@ c$.zeta2 =  Clazz.newDoubleArray(-1, [0, 1., 1., 0.9992, 0.6945, 0.5300, 0.5480,
 c$.zeta3 =  Clazz.newDoubleArray(-1, [0, 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.0236, 0.7753, 0.5962, 0.6995, 0.5851, 0.5149, 0.4974, 0.4412]);
 c$.dMax =  Clazz.newDoubleArray(-1, [0, 2.982502423, 2.635120936, 4.144887422, 4.105800759, 3.576656363, 3.872424373, 3.497503547, 3.165369971, 3.204214082, 3.051069564, 4.251312809, 4.503309314, 4.047465141, 4.666024968, 4.265151411, 3.955710076, 4.040067606, 3.776022242]);
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
