@@ -142,4 +142,4 @@ vd[(havePoints ? 0 : iz)] += (f0 + f1p + f1n + f2p + f2n + f3p + f3n) * eXY * ca
 return true;
 }, "J.quantum.MOCalculation,~B");
 });
-;//5.0.1-v7 Wed Apr 02 04:50:42 CDT 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
