@@ -16,4 +16,4 @@ return false;
 }
 }, "J.quantum.MOCalculation,~B");
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
