@@ -196,4 +196,4 @@ var yStrBaseline = Math.floor(y + strAscent / 2);
 this.g3d.drawString(str, this.font3d, Clazz.doubleToInt(xStrBaseline), Clazz.doubleToInt(yStrBaseline), Clazz.floatToInt(z), Clazz.floatToInt(z), 0);
 }, "~S,~N,~N,~N,~N,~N");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
