@@ -108,4 +108,4 @@ this.shiftC = ((this.periodicity & 0x4) == 0);
 this.shifting = (this.shiftA || this.shiftB || this.shiftC);
 });
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
