@@ -111,16 +111,20 @@ var band = this.vwr.getRubberBandSelection();
 if (band != null && g3d.setC(this.vwr.cm.colixRubberband)) g3d.drawRect(band.x, band.y, 0, 0, band.width, band.height);
 this.vwr.noFrankEcho = true;
 }var msg = null;
+var sticks = this.shapeManager.getShape(1);
+sticks.haveStrutPoints = false;
 for (var i = 0; i < 37 && gdata.currentlyRendering; ++i) {
 var shape = this.shapeManager.getShape(i);
 if (shape == null) continue;
 if (logTime) {
 msg = "rendering " + JV.JC.getShapeClassName(i, false);
 JU.Logger.startTimer(msg);
-}if ((isFirstPass || this.bsTranslucent.get(i)) && this.getRenderer(i).renderShape(g3d, modelSet, shape)) this.bsTranslucent.set(i);
+}if ((isFirstPass || this.bsTranslucent.get(i)) && this.getRenderer(i).renderShape(g3d, modelSet, shape, 0)) this.bsTranslucent.set(i);
 if (logTime) JU.Logger.checkTimer(msg, false);
 }
-g3d.renderAllStrings(null);
+if (sticks.haveStrutPoints) {
+this.getRenderer(1).renderShape(g3d, modelSet, sticks, 1);
+}g3d.renderAllStrings(null);
 } catch (e) {
 if (Clazz.exceptionOf(e, Exception)){
 e.printStackTrace();
@@ -155,16 +159,20 @@ var msg = null;
 try {
 var logTime = this.vwr.getBoolean(603979934);
 exporter3D.renderBackground(exporter3D);
+var sticks = this.shapeManager.getShape(1);
+sticks.haveStrutPoints = false;
 for (var i = 0; i < 37; ++i) {
 var shape = this.shapeManager.getShape(i);
 if (shape == null) continue;
 if (logTime) {
 msg = "rendering " + JV.JC.getShapeClassName(i, false);
 JU.Logger.startTimer(msg);
-}this.getRenderer(i).renderShape(exporter3D, modelSet, shape);
+}this.getRenderer(i).renderShape(exporter3D, modelSet, shape, 0);
 if (logTime) JU.Logger.checkTimer(msg, false);
 }
-exporter3D.renderAllStrings(exporter3D);
+if (sticks.haveStrutPoints) {
+this.getRenderer(1).renderShape(exporter3D, modelSet, sticks, 1);
+}exporter3D.renderAllStrings(exporter3D);
 msg = exporter3D.finalizeOutput();
 } catch (e) {
 if (Clazz.exceptionOf(e, Exception)){
@@ -177,4 +185,4 @@ throw e;
 return msg;
 }, "JU.GData,JM.ModelSet,java.util.Map");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 16:40:34 CDT 2025
