@@ -12,6 +12,7 @@ this.colix = 0;
 this.mad = 0;
 this.exportType = 0;
 this.isExport = false;
+this.flags = 0;
 Clazz.instantialize(this, arguments);}, J.render, "ShapeRenderer", null);
 Clazz.defineMethod(c$, "initRenderer", 
 function(){
@@ -25,13 +26,14 @@ this.myVisibilityFlag = JV.JC.getShapeVisibilityFlag(shapeID);
 this.initRenderer();
 }, "JV.Viewer,~N");
 Clazz.defineMethod(c$, "renderShape", 
-function(g3d, modelSet, shape){
+function(g3d, modelSet, shape, flags){
 this.setup(g3d, modelSet, shape);
+this.flags = flags;
 var needsTranslucent = this.render();
 this.exportType = 0;
 this.isExport = false;
 return needsTranslucent;
-}, "J.api.JmolRendererInterface,JM.ModelSet,J.shape.Shape");
+}, "J.api.JmolRendererInterface,JM.ModelSet,J.shape.Shape,~N");
 Clazz.defineMethod(c$, "setup", 
 function(g3d, modelSet, shape){
 this.g3d = g3d;
@@ -42,7 +44,7 @@ this.isExport = (this.exportType != 0);
 }, "J.api.JmolRendererInterface,JM.ModelSet,J.shape.Shape");
 Clazz.defineMethod(c$, "isVisibleForMe", 
 function(a){
-return a.isVisible(this.myVisibilityFlag | 9);
+return a != null && a.isVisible(this.myVisibilityFlag | 9);
 }, "JM.Atom");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 16:40:34 CDT 2025
