@@ -47,4 +47,4 @@ if (this.mar > 0) this.g3d.fillCylinderXYZ(this.colix, this.colix, 2, this.width
  else this.g3d.drawLineXYZ(xA, yA, zA, xB, yB, zB);
 }, "~N,~N,~N,~N,~N,~N");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
