@@ -15,6 +15,8 @@ this.bondsBackbone = false;
 this.hbondsSolid = false;
 this.a = null;
 this.b = null;
+this.pa = null;
+this.pb = null;
 this.bond = null;
 this.xA = 0;
 this.yA = 0;
@@ -38,6 +40,7 @@ this.p2 = null;
 this.bsForPass2 = null;
 this.isPass2 = false;
 this.isPymol = false;
+this.strutsOnly = false;
 this.xAxis1 = 0;
 this.yAxis1 = 0;
 this.xAxis2 = 0;
@@ -73,23 +76,24 @@ this.hbondsBackbone = this.vwr.getBoolean(603979852);
 this.bondsBackbone =  new Boolean (this.hbondsBackbone | this.ssbondsBackbone).valueOf();
 this.hbondsSolid = this.vwr.getBoolean(603979854);
 this.isAntialiased = this.g3d.isAntialiased();
+this.strutsOnly = ((this.flags & 1) != 0);
 var needTranslucent = false;
 if (this.isPass2) {
-if (!this.isExport) for (var i = this.bsForPass2.nextSetBit(0); i >= 0; i = this.bsForPass2.nextSetBit(i + 1)) {
+for (var i = this.bsForPass2.nextSetBit(0); i >= 0; i = this.bsForPass2.nextSetBit(i + 1)) {
 this.bond = bonds[i];
-if (this.bond != null) this.renderBond();
+if (this.bond != null) this.renderBond(i);
 }
 } else {
 for (var i = this.ms.bondCount; --i >= 0; ) {
 this.bond = bonds[i];
-if (this.bond != null && (this.bond.shapeVisibilityFlags & this.myVisibilityFlag) != 0 && this.renderBond()) {
+if (this.bond != null && (this.bond.shapeVisibilityFlags & this.myVisibilityFlag) != 0 && this.renderBond(i)) {
 needTranslucent = true;
 this.bsForPass2.set(i);
 }}
 }return needTranslucent;
 });
 Clazz.defineMethod(c$, "renderBond", 
-function(){
+function(index){
 var atomA0;
 var atomB0;
 this.a = atomA0 = this.bond.atom1;
@@ -119,22 +123,34 @@ this.colixB = JU.C.getColixInherited((this.colix | this.vwr.cm.getColixAtomPalet
 this.colixA = JU.C.getColixInherited(this.colix, this.colixA);
 this.colixB = JU.C.getColixInherited(this.colix, this.colixB);
 }var needTranslucent = false;
-if (!this.isExport && !this.isPass2) {
+var skip = false;
+this.bondOrder = order & 131071;
+var isStrut = (this.bondOrder == 32768);
+if (this.strutsOnly != isStrut) {
+if (isStrut) {
+(this.shape).haveStrutPoints = true;
+if (!this.isPass2) {
+this.a.group.unsetStrutPoint();
+this.b.group.unsetStrutPoint();
+}}skip = true;
+}if (!this.isExport && !this.isPass2) {
 var doA = !JU.C.renderPass2(this.colixA);
 var doB = !JU.C.renderPass2(this.colixB);
 if (!doA || !doB) {
-if (!doA && !doB && !needTranslucent) {
-this.g3d.setC(!doA ? this.colixA : this.colixB);
-return true;
-}needTranslucent = true;
-}}this.bondOrder = order & 131071;
+if (isStrut || !doA && !doB) {
+skip = true;
+}this.g3d.setC(!doA ? this.colixB : this.colixA);
+needTranslucent = true;
+}}if (skip) return needTranslucent;
 var isPartial = this.bond.isPartial();
 if (!isPartial) {
 if ((this.bondOrder & 256) != 0) this.bondOrder &= -257;
 if ((this.bondOrder & 1023) != 0) {
 if (!this.showMultipleBonds || (this.modeMultipleBond == 2 && this.mad > 1000) || (this.bondOrder & 98304) == 65536) {
 this.bondOrder = 1;
-}}}var mask = 0;
+}}}this.pa = this.a;
+this.pb = this.b;
+var mask = 0;
 switch (this.bondOrder) {
 case 1025:
 case 1041:
@@ -168,13 +184,19 @@ mask = JU.Edge.getPartialBondDotted(order);
 } else if (JU.Edge.isOrderH(this.bondOrder)) {
 this.bondOrder = 1;
 if (!this.hbondsSolid) mask = -1;
-} else if (this.bondOrder == 32768) {
+} else if (isStrut) {
 this.bondOrder = 1;
+var p1 = this.a.group.strutPoint;
+var p2 = this.b.group.strutPoint;
+this.pa = this.setStrutPoint(p1, this.pa);
+this.pb = this.setStrutPoint(p2, this.pb);
+this.zA = this.pa.sZ;
+this.zB = this.pb.sZ;
 }}
-this.xA = this.a.sX;
-this.yA = this.a.sY;
-this.xB = this.b.sX;
-this.yB = this.b.sY;
+this.xA = this.pa.sX;
+this.yA = this.pa.sY;
+this.xB = this.pb.sX;
+this.yB = this.pb.sY;
 this.mad = this.bond.mad;
 if (this.multipleBondRadiusFactor > 0 && this.bondOrder > 1) this.mad *= this.multipleBondRadiusFactor;
 this.dx = this.xB - this.xA;
@@ -250,7 +272,16 @@ this.drawBond(mask);
 break;
 }
 return needTranslucent;
-});
+}, "~N");
+Clazz.defineMethod(c$, "setStrutPoint", 
+function(p, a){
+if (p.sX == -2147483648) return a;
+var pi = this.vwr.tm.transformPt(p);
+p.sX = pi.x;
+p.sY = pi.y;
+p.sZ = pi.z;
+return p;
+}, "JU.Point3fi,JU.Point3fi");
 Clazz.defineMethod(c$, "getMultipleBondSettings", 
 function(pymolBondOrder){
 this.isPymol = (pymolBondOrder != 0);
@@ -277,7 +308,7 @@ function(dottedMask){
 var isDashed = (dottedMask & 1) != 0;
 var endcaps = ((this.colixA & 30720) == 16384 || (this.colixB & 30720) == 16384 ? 2 : this.endcaps);
 if (this.isCartesian && this.bondOrder == 1 && !isDashed) {
-this.g3d.drawBond(this.a, this.b, this.colixA, this.colixB, endcaps, this.mad, -1);
+this.g3d.drawBond(this.pa, this.pb, this.colixA, this.colixB, endcaps, this.mad, -1);
 return;
 }var isEndOn = (this.dx == 0 && this.dy == 0);
 if (isEndOn && this.asLineOnly && !this.isCartesian) return;
@@ -424,4 +455,4 @@ this.g3d.setC(this.colixB);
 this.g3d.fillHermite(5, w, w, w, this.pointT, this.pointT2, this.pointT3, this.pointT3);
 }, "JM.Atom,JM.Atom,JU.V3,~N");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 16:40:34 CDT 2025
