@@ -19,8 +19,12 @@ var cB = this.colixes[i1];
 if (atomA.nBackbonesDisplayed > 0 && atomB.nBackbonesDisplayed > 0 && !this.ms.isAtomHidden(atomB.i) && (this.isDataFrame || atomA.distanceSquared(atomB) < 100)) {
 cA = JU.C.getColixInherited(cA, atomA.colixAtom);
 cB = JU.C.getColixInherited(cB, atomB.colixAtom);
-if (!checkPass2 || this.setBioColix(cA) || this.setBioColix(cB)) this.drawSegmentAB(atomA, atomB, cA, cB, 100);
-}}
+if (!checkPass2 || this.setBioColix(cA) || this.setBioColix(cB)) {
+this.drawSegmentAB(atomA, atomB, cA, cB, 100);
+if (this.renderStruts) {
+this.setStrutPoint(atomA, null);
+this.setStrutPoint(atomB, null);
+}}}}
 }, "J.shapebio.BioShape");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
