@@ -76,15 +76,16 @@ throw e;
 Clazz.defineMethod(c$, "setFancyConic", 
 function(i, tension){
 try {
-if ((this.meshes[i] == null || !this.meshReady[i]) && !this.createMesh(i, this.bsr.madBeg, this.bsr.madMid, this.bsr.madEnd, 1, tension)) return;
+if ((this.meshes[i] == null || !this.meshReady[i]) && !this.createMesh(i, this.bsr.madBeg, this.bsr.madMid, this.bsr.madEnd, 1, tension)) return false;
 this.meshes[i].setColix(this.bsr.colix);
 this.bsRenderMesh.set(i);
-return;
+return true;
 } catch (e) {
 if (Clazz.exceptionOf(e, Exception)){
 this.bsRenderMesh.clear(i);
 this.meshes[i] = null;
 JU.Logger.error("render mesh error hermiteConic: " + e.toString());
+return false;
 } else {
 throw e;
 }
@@ -277,4 +278,4 @@ function(d){
 return (this.bsr.isHighRes && d > 3 || d >= 8);
 }, "~N");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
