@@ -1,5 +1,5 @@
 Clazz.declarePackage("J.renderbio");
-Clazz.load(["J.render.ShapeRenderer", "JU.BS", "$.P3"], "J.renderbio.BioShapeRenderer", ["javajs.api.Interface", "J.c.STR", "JU.C"], function(){
+Clazz.load(["J.render.ShapeRenderer", "JU.BS", "$.P3"], "J.renderbio.BioShapeRenderer", ["javajs.api.Interface", "J.c.STR", "JU.C", "$.Point3fi"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.invalidateMesh = false;
 this.invalidateSheets = false;
@@ -29,6 +29,7 @@ this.structureTypes = null;
 this.isHighRes = false;
 this.wireframeOnly = false;
 this.needTranslucent = false;
+this.renderStruts = false;
 this.meshRenderer = null;
 this.bioShape = null;
 this.pointT = null;
@@ -105,7 +106,8 @@ if (fval != this.sheetSmoothing && this.isTraceAlpha) {
 this.sheetSmoothing = fval;
 this.invalidateMesh = true;
 this.invalidateSheets = true;
-}});
+}this.renderStruts = (this.vwr.shm.getShape(1)).haveStrutPoints;
+});
 Clazz.defineMethod(c$, "renderShapes", 
 function(){
 var mps = this.shape;
@@ -260,17 +262,28 @@ Clazz.defineMethod(c$, "renderHermiteConic",
 function(i, thisTypeOnly, tension){
 this.setNeighbors(i);
 this.colix = this.getLeadColix(i);
+this.checkStruts(i);
 if (!this.setBioColix(this.colix)) return;
 if (this.setMads(i, thisTypeOnly) || this.isExport) {
-this.meshRenderer.setFancyConic(i, tension);
-return;
-}if (this.diameterBeg == 0 && this.diameterEnd == 0 || this.wireframeOnly) this.g3d.drawLineAB(this.controlPointScreens[i], this.controlPointScreens[this.iNext]);
- else {
+if (!this.meshRenderer.setFancyConic(i, tension)) return;
+} else {
+if (this.diameterBeg == 0 && this.diameterEnd == 0 || this.wireframeOnly) {
+this.g3d.drawLineAB(this.controlPointScreens[i], this.controlPointScreens[this.iNext]);
+} else {
 this.g3d.fillHermite(this.isNucleic ? 4 : 7, this.diameterBeg, this.diameterMid, this.diameterEnd, this.controlPointScreens[this.iPrev], this.controlPointScreens[i], this.controlPointScreens[this.iNext], this.controlPointScreens[this.iNext2]);
-}}, "~N,~B,~N");
+}}}, "~N,~B,~N");
+Clazz.defineMethod(c$, "checkStruts", 
+function(i){
+if (this.renderStruts && this.monomers[i].isSheet() && this.monomers[i].strutPoint != null) {
+var p =  new JU.Point3fi();
+p.add2(this.controlPoints[i], this.controlPoints[i + 1]);
+p.scale(0.5);
+this.setStrutPoint(this.monomers[i].getLeadAtom(), p);
+}}, "~N");
 Clazz.defineMethod(c$, "renderHermiteRibbon", 
 function(doFill, i, thisTypeOnly){
 this.setNeighbors(i);
+this.checkStruts(i);
 var c0 = this.colix = this.getLeadColix(i);
 if (!this.setBioColix(this.colix)) return;
 var cb = this.colixBack = this.getLeadColixBack(i);
@@ -323,5 +336,20 @@ this.g3d.drawLine(colixA, colixB, xA, yA, zA, xB, yB, zB);
 var width = Clazz.floatToInt(this.isExport ? mad : this.vwr.tm.scaleToScreen(Clazz.doubleToInt((zA + zB) / 2), mad));
 this.g3d.fillCylinderXYZ(colixA, colixB, 3, width, xA, yA, zA, xB, yB, zB);
 }}, "JM.Atom,JM.Atom,~N,~N,~N");
+Clazz.defineMethod(c$, "getStrutPointIfNeeded", 
+function(a){
+var p = a.group.strutPoint;
+return (p != null && p.sX == -2147483648 ? p : null);
+}, "JM.Atom");
+Clazz.defineMethod(c$, "setStrutPoint", 
+function(a, newPt){
+var p = this.getStrutPointIfNeeded(a);
+if (p == null) return;
+if (newPt == null) newPt = a;
+p.setP(newPt);
+p.sX = newPt.sX;
+p.sY = newPt.sY;
+p.sZ = newPt.sZ;
+}, "JM.Atom,JU.Point3fi");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 16:40:34 CDT 2025
