@@ -54,4 +54,4 @@ lastWasHelix = isHelix && !this.helixRockets;
 if (doRockets) this.renderRockets();
 });
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
