@@ -71,9 +71,16 @@ function(){
 if (!this.tPending) return;
 var segments = this.proteinstructurePending.getSegments();
 var renderArrowHead = (this.renderArrowHeads && this.endIndexPending == this.proteinstructurePending.nRes - 1);
-if (Clazz.instanceOf(this.proteinstructurePending,"JM.Helix")) this.renderPendingRocketSegment(this.endIndexPending, segments[this.startIndexPending], segments[this.endIndexPending], segments[this.endIndexPending + 1], renderArrowHead);
- else if (Clazz.instanceOf(this.proteinstructurePending,"JM.Sheet") && Clazz.instanceOf((this.proteinstructurePending).apolymer,"JM.AminoPolymer")) this.renderPendingSheetPlank(segments[this.startIndexPending], segments[this.endIndexPending], segments[this.endIndexPending + 1], renderArrowHead);
+if (Clazz.instanceOf(this.proteinstructurePending,"JM.Helix")) {
+this.renderPendingRocketSegment(this.endIndexPending, segments[this.startIndexPending], segments[this.endIndexPending], segments[this.endIndexPending + 1], renderArrowHead);
+} else if (Clazz.instanceOf(this.proteinstructurePending,"JM.Sheet") && Clazz.instanceOf((this.proteinstructurePending).apolymer,"JM.AminoPolymer")) {
+this.renderPendingSheetPlank(segments[this.startIndexPending], segments[this.endIndexPending], segments[this.endIndexPending + 1], renderArrowHead);
+} else {
 this.tPending = false;
+return;
+}if (this.rr.renderStruts) {
+this.rr.adjustStrut(segments, this.startIndexPending, this.endIndexPending, this.proteinstructurePending.monomerIndexFirst);
+}this.tPending = false;
 });
 Clazz.defineMethod(c$, "renderPendingRocketSegment", 
 function(i, pointStart, pointBeforeEnd, pointEnd, renderArrowHead){
@@ -89,7 +96,6 @@ this.tm.transformPt3f(pointEnd, this.screenC);
 var coneDiameter = (this.mad << 1) - (this.mad >> 1);
 coneDiameter = Clazz.floatToInt(this.vwr.tm.scaleToScreen(Clazz.doubleToInt(Math.floor(this.screenB.z)), coneDiameter));
 this.g3d.fillConeScreen3f(2, coneDiameter, this.screenB, this.screenC, false);
-} else {
 }if (this.startIndexPending == this.endIndexPending) return;
 var t = this.screenB;
 this.screenB = this.screenC;
@@ -165,4 +171,4 @@ if (f.length == 3) this.g3d.fillTriangle3f(this.screenCorners[f[0]], this.screen
 c$.boxFaces =  Clazz.newArray(-1, [ Clazz.newIntArray(-1, [0, 1, 3, 2]),  Clazz.newIntArray(-1, [0, 2, 6, 4]),  Clazz.newIntArray(-1, [0, 4, 5, 1]),  Clazz.newIntArray(-1, [7, 5, 4, 6]),  Clazz.newIntArray(-1, [7, 6, 2, 3]),  Clazz.newIntArray(-1, [7, 3, 1, 5])]);
 c$.arrowHeadFaces =  Clazz.newArray(-1, [ Clazz.newIntArray(-1, [1, 0, 4]),  Clazz.newIntArray(-1, [2, 3, 5]),  Clazz.newIntArray(-1, [0, 1, 3, 2]),  Clazz.newIntArray(-1, [2, 5, 4, 0]),  Clazz.newIntArray(-1, [1, 4, 5, 3])]);
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
