@@ -64,5 +64,15 @@ proteinstructurePrev = null;
 this.controlPoints = this.cordMidPoints;
 this.calcScreenControlPoints();
 });
+Clazz.defineMethod(c$, "adjustStrut", 
+function(segments, start, end, offset){
+for (var i = start; i <= end; i++) {
+var a = this.monomers[i + offset].getLeadAtom();
+var pt = this.getStrutPointIfNeeded(a);
+if (pt != null) {
+pt.setT(segments[i]);
+pt.sX = 0;
+}}
+}, "~A,~N,~N,~N");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
