@@ -55,4 +55,4 @@ this.g3d.fillTriangle3CNBits(this.facePt1, this.colix, p1, this.facePt2, this.co
 }
 }, "JU.BS");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
