@@ -184,4 +184,4 @@ if (this.standardVector) this.g3d.fillCylinderBits(2, this.diameter, this.pTemp3
 }if (this.drawCap) this.g3d.fillConeScreen3f(2, this.headWidthPixels, this.screenArrowHead, this.screenVectorEnd, false);
 }, "JM.Atom,JU.Vibration");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 16:37:14 CDT 2025
