@@ -2,4 +2,4 @@ Clazz.declarePackage("J.rendersurface");
 Clazz.load(["J.rendersurface.MolecularOrbitalRenderer"], "J.rendersurface.NBORenderer", null, function(){
 var c$ = Clazz.declareType(J.rendersurface, "NBORenderer", J.rendersurface.MolecularOrbitalRenderer);
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Sun May 18 17:15:27 CDT 2025
