@@ -3,6 +3,7 @@ Clazz.load(["J.shape.Shape", "JU.P3i"], "J.shape.Sticks", ["java.util.Hashtable"
 var c$ = Clazz.decorateAsClass(function(){
 this.myMask = 0;
 this.reportAll = false;
+this.haveStrutPoints = false;
 this.bsOrderSet = null;
 this.selectedBonds = null;
 this.closestAtom = null;
@@ -166,4 +167,4 @@ pt.setT(v);
 return pickedBond;
 }, "~N,~N,JU.BS,JU.P3,~A");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 16:40:34 CDT 2025
