@@ -398,4 +398,4 @@ if (this.scale != 1) sb.append("; scale:" + this.scale);
 sb.append("\n");
 }, "JU.SB");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 13:18:25 CDT 2025
