@@ -224,4 +224,4 @@ this.lcaoReverseColor = lc.lcaoReverseColor;
 Clazz.superCall(this, J.shapesurface.LcaoCartoon, "merge", [shape]);
 }, "J.shape.MeshCollection");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
