@@ -152,4 +152,4 @@ return JU.Quat.getQuaternionFrameV(vA, vB, vC, false);
 }, "~S");
 c$.alphaOffsets =  Clazz.newByteArray(-1, [0]);
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Sun May 18 19:15:32 CDT 2025
