@@ -221,4 +221,4 @@ for (var j = b.length; --j >= 0; ) if ((h = b[j].getOtherAtom(a)).getElementNumb
 }, "JU.BS,JM.Atom,~B");
 c$.interestingAminoAtomIDs =  Clazz.newByteArray(-1, [2, -5, 1, 3, -65]);
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Sun May 18 19:15:32 CDT 2025
