@@ -657,4 +657,4 @@ function(s, atomName, aaRet){
 return this.getBioExt().getAminoAcidValenceAndCharge(s, atomName, aaRet);
 }, "~S,~S,~A");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 15:33:04 CDT 2025
