@@ -1,5 +1,5 @@
 Clazz.declarePackage("JM");
-Clazz.load(["JM.Structure", "java.lang.Short", "JV.JC"], "JM.Group", ["java.util.Hashtable", "JU.BS", "$.Quat", "J.c.STR", "JU.BSUtil", "$.Escape", "$.Logger"], function(){
+Clazz.load(["JM.Structure", "java.lang.Short", "JV.JC"], "JM.Group", ["java.util.Hashtable", "JU.BS", "$.Quat", "J.c.STR", "JU.BSUtil", "$.Escape", "$.Logger", "$.Point3fi"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.chain = null;
 this.groupIndex = 0;
@@ -13,6 +13,7 @@ this.groupID = 0;
 this.selectedIndex = 0;
 this.shapeVisibilityFlags = 0;
 this.dssrNT = null;
+this.strutPoint = null;
 Clazz.instantialize(this, arguments);}, JM, "Group", null, JM.Structure);
 /*LV!1824 unnec constructor*/Clazz.defineMethod(c$, "setGroup", 
 function(chain, group3, seqcode, firstAtomIndex, lastAtomIndex){
@@ -328,8 +329,13 @@ Clazz.defineMethod(c$, "isNucleicMonomer",
 function(){
 return false;
 });
+Clazz.defineMethod(c$, "unsetStrutPoint", 
+function(){
+if (this.strutPoint == null) this.strutPoint =  new JU.Point3fi();
+this.strutPoint.sX = -2147483648;
+});
 c$.standardGroupList = null;
 c$.group3Names =  new Array(128);
 c$.specialAtomNames = null;
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 16:40:34 CDT 2025
