@@ -20,4 +20,4 @@ this.axisB = JU.P3.newP(points[this.nRes]);
 JU.Measure.projectOntoAxis(this.axisB, this.axisA, this.axisUnitVector, this.vectorProjection);
 });
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Sun May 18 19:15:32 CDT 2025
