@@ -18,8 +18,8 @@ this.vdwKey = null;
 this.bs14 = null;
 Clazz.instantialize(this, arguments);}, JM, "MinAtom", null);
 Clazz.prepareFields (c$, function(){
-this.coord =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
-this.force =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
+this.coord =  Clazz.newDoubleArray (3, 0);
+this.force =  Clazz.newDoubleArray (3, 0);
 this.bonds =  new JU.Lst();
 this.bsVdw =  new JU.BS();
 this.bs14 =  new JU.BS();
@@ -52,7 +52,7 @@ return null;
 Clazz.defineMethod(c$, "getBondedAtomIndexes", 
 function(){
 if (this.bondedAtoms == null) {
-this.bondedAtoms =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nBonds, 0);
+this.bondedAtoms =  Clazz.newIntArray (this.nBonds, 0);
 for (var i = this.nBonds; --i >= 0; ) this.bondedAtoms[i] = this.bonds.get(i).getOtherAtom(this.index);
 
 }return this.bondedAtoms;
@@ -77,4 +77,4 @@ if (this.hCount < 0) this.hCount = this.atom.getCovalentHydrogenCount();
 return this.hCount;
 });
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
