@@ -97,8 +97,10 @@ this.ms.msInfo = info;
 this.ms.modelSetProperties = this.ms.getInfoM("properties");
 this.ms.haveBioModels = this.ms.getMSInfoB(JV.JC.getBoolName(4));
 this.isMutate = this.ms.getMSInfoB("isMutate");
-if (this.ms.haveBioModels) this.jbr = this.vwr.getJBR().setLoader(this);
-this.jmolData = (this.adapterModelCount == 0 ? this.ms.getInfoM("jmolData") : null);
+if (this.ms.haveBioModels) {
+this.jbr = this.vwr.getJBR().setLoader(this);
+this.jbr.carbohydrates = info.get("carbohydrates");
+}this.jmolData = (this.adapterModelCount == 0 ? this.ms.getInfoM("jmolData") : null);
 this.fileHeader = this.ms.getInfoM("fileHeader");
 var steps = this.ms.getInfoM("trajectorySteps");
 this.isTrajectory = (steps != null);
@@ -1066,4 +1068,4 @@ break;
 return null;
 }, "JV.Viewer,JM.ModelSet,~N,~O,JU.BS");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 15:33:04 CDT 2025
