@@ -77,4 +77,4 @@ return this.getHelixData2(tokType, qType, mStep);
 c$.phosphorusOffsets =  Clazz.newByteArray(-1, [0]);
 c$.MAX_ADJACENT_PHOSPHORUS_DISTANCE = 8.0;
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Sun May 18 17:21:41 CDT 2025
