@@ -69,4 +69,4 @@ ptC.ave(vW, vH);
 ptC.sub2(pt, ptC);
 }, "~N,~N,JU.P3,JU.V3,JU.V3,JU.P3,~N");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Sun May 18 19:15:32 CDT 2025
