@@ -8,4 +8,4 @@ this.setupPS(apolymer, J.c.STR.TURN, monomerIndex, monomerCount);
 this.subtype = J.c.STR.TURN;
 }, "JM.AlphaPolymer,~N,~N");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Sun May 18 19:15:32 CDT 2025
