@@ -33,4 +33,4 @@ function(margins){
 return "style='" + (margins ? "margin:" + this.insets.top + "px " + (this.ipady + this.insets.right) + "px " + this.insets.bottom + "px " + (this.ipadx + this.insets.left) + "px;" : "text-align:" + (this.anchor == 13 ? "right" : this.anchor == 17 ? "left" : "center")) + "'";
 }, "~B");
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
