@@ -20,4 +20,4 @@ return JS.InvalidSmilesException.lastError;
 });
 c$.lastError = null;
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
