@@ -1193,6 +1193,13 @@ var o2;
 var m3 = null;
 var m4 = null;
 switch (this.tok) {
+case 10:
+o2 =  new JU.Lst();
+var bs = JS.SV.getBitSet(this, true);
+for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
+o2.addLast(JS.SV.newI(i));
+}
+return JS.SV.newV(7, o2);
 case 11:
 m3 = this.value;
 dim = 3;
@@ -1459,4 +1466,4 @@ c$.vF = JS.SV.newSV(1073742334, 0, "false");
 c$.vNaN = JS.SV.newSV(3, 2147483647, Float.$valueOf(NaN));
 c$.pt0 =  new JU.P3();
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
