@@ -72,10 +72,11 @@ throw ex;
 return 0;
 }, "JU.BS,JU.BS,~S,JU.Lst,JU.Lst,JU.M4,JU.Lst,~B,~A,JU.P3,~B,~N");
 Clazz.defineMethod(c$, "getSmilesMatches", 
-function(pattern, smiles, bsSelected, bsMatch3D, flags, asOneBitset, firstMatchOnly){
-if (pattern.length == 0 || pattern.endsWith("///") || pattern.equals("H") || pattern.equals("H2") || pattern.equals("top") || pattern.equalsIgnoreCase("NOAROMATIC")) {
+function(patternObj, smilesObj, bsSelected, bsMatch3D, flags, asOneBitset, firstMatchOnly){
+var info = ((typeof(patternObj)=='string') ? patternObj : "-");
+if ((info.length == 0 || info.endsWith("///") || info.equals("H") || info.equals("H2") || info.equals("top") || info.equalsIgnoreCase("NOAROMATIC"))) {
 try {
-return this.e.vwr.getSmilesOpt(bsSelected, 0, 0, flags | (pattern.equals("H2") ? 8192 : 0) | (pattern.equals("H") ? 4096 : 0) | (pattern.equals("top") ? 16384 : 0) | (pattern.equalsIgnoreCase("NOAROMATIC") ? 16 : 0), (pattern.endsWith("///") ? pattern : null));
+return this.e.vwr.getSmilesOpt(bsSelected, 0, 0, flags | (info.equals("H2") ? 8192 : 0) | (info.equals("H") ? 4096 : 0) | (info.equals("top") ? 16384 : 0) | (info.equalsIgnoreCase("NOAROMATIC") ? 16 : 0), (info.endsWith("///") ? info : null));
 } catch (ex) {
 if (Clazz.exceptionOf(ex, Exception)){
 this.e.evalError(ex.getMessage(), null);
@@ -86,17 +87,17 @@ throw ex;
 }var b;
 if (bsMatch3D == null) {
 try {
-if (smiles == null) {
-b = this.e.vwr.getSubstructureSetArray(pattern, bsSelected, flags);
-} else if (pattern.equals("chirality")) {
-return this.e.vwr.calculateChiralityForSmiles(smiles);
+if (smilesObj == null) {
+b = this.e.vwr.getSubstructureSetArray(patternObj, bsSelected, flags);
+} else if ("chirality".equals(info)) {
+return this.e.vwr.calculateChiralityForSmiles(smilesObj.toString());
 } else {
 var isSmarts = ((flags & 2) == 2);
 var ignoreElements = ((flags & 16384) == 16384);
 flags = (isSmarts ? 2 : 1) | (firstMatchOnly ? 8 : 0) | (ignoreElements ? 16384 : 0);
-if (!((typeof(smiles)=='string'))) {
-return this.e.vwr.getSmilesMatcher().hasStructure(pattern, smiles, flags);
-}var map = this.e.vwr.getSmilesMatcher().find(pattern, smiles, flags);
+if (Clazz.instanceOf(smilesObj,Array)) {
+return this.e.vwr.getSmilesMatcher().hasStructure(info, smilesObj, flags);
+}var map = this.e.vwr.getSmilesMatcher().find(patternObj, smilesObj, flags);
 if (!asOneBitset) return (!firstMatchOnly ? map : map.length == 0 ?  Clazz.newIntArray (0, 0) : map[0]);
 var bs =  new JU.BS();
 for (var j = 0; j < map.length; j++) {
@@ -120,7 +121,7 @@ throw ex;
 }
 } else {
 var vReturn =  new JU.Lst();
-var stddev = this.getSmilesCorrelation(bsMatch3D, bsSelected, pattern, null, null, null, vReturn, false, null, null, false, flags);
+var stddev = this.getSmilesCorrelation(bsMatch3D, bsSelected, info, null, null, null, vReturn, false, null, null, false, flags);
 if (Float.isNaN(stddev)) return (asOneBitset ?  new JU.BS() :  Clazz.newArray(-1, []));
 this.e.showString("RMSD " + stddev + " Angstroms");
 b = vReturn.toArray( new Array(vReturn.size()));
@@ -133,7 +134,7 @@ return bs;
 for (var j = 0; j < b.length; j++) list.addLast(b[j]);
 
 return list;
-}, "~S,~O,JU.BS,JU.BS,~N,~B,~B");
+}, "~O,~O,JU.BS,JU.BS,~N,~B,~B");
 Clazz.defineMethod(c$, "getFlexFitList", 
 function(bs1, bs2, smiles1, isSmarts){
 var mapSet = JU.AU.newInt2(2);
@@ -198,4 +199,4 @@ J.api.Interface.getInterface("JU.Eigen", this.e.vwr, "script");
 return JU.Measure.getTransformMatrix4(ptsA, ptsB, m, null);
 }, "~N,~N,~B,JU.M4");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 13:18:25 CDT 2025
