@@ -930,4 +930,4 @@ JS.SmilesParser.extractFlags(pattern, ret);
 return ret[0];
 }, "~S");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 16:40:34 CDT 2025
