@@ -125,6 +125,13 @@ if (strFlags.indexOf("COVALENT") >= 0) flags |= 5242880;
 if (strFlags.indexOf("HBOND") >= 0) flags |= 9437184;
 }return flags;
 }, "~N,~S");
+Clazz.defineMethod(c$, "reset", 
+function(){
+this.vReturn = null;
+this.noAromatic = false;
+this.exitFirstMatch = false;
+this.flags = 0;
+});
 Clazz.defineMethod(c$, "setFlags", 
 function(flags){
 this.flags = flags;
@@ -1052,6 +1059,10 @@ return "molecular formula: " + this.target.getMolecularFormula(true, null, false
 sb.append("\nmolecular formula: " + this.getMolecularFormula(true, null, false));
 return sb.toString();
 });
+Clazz.overrideMethod(c$, "equals", 
+function(ss){
+return (Clazz.instanceOf(ss,"JS.SmilesSearch")) && (this.pattern0 == null ? (ss).pattern0 == null : this.pattern0.equals((ss).pattern0));
+}, "~O");
 /*if3*/;(function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.bsSelected = null;
@@ -1164,4 +1175,4 @@ return false;
 });
 /*eoif3*/})();
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 16:40:34 CDT 2025
