@@ -34,4 +34,4 @@ function(sym, vwr, name, type){
 return this.createSpecialGroup(null, sym, JS.Symmetry.getSpecialSettingInfo(vwr, name, type), type);
 }, "JS.Symmetry,JV.Viewer,~S,~N");
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
