@@ -23,4 +23,4 @@ this.vNorm4 =  new JU.V3();
 this.bsTemp =  new JU.BS();
 });
 });
-;//5.0.1-v7 Wed Apr 02 04:50:42 CDT 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
