@@ -372,4 +372,4 @@ function(){
 return "JSpecView Applet " + JSV.common.JSVersion.VERSION + "\n\n" + "Authors:\nProf. Robert M. Hanson,\nD. Facey, K. Bryan, C. Walters, Prof. Robert J. Lancashire and\nvolunteer developers through sourceforge.";
 });
 });
-;//5.0.1-v2 Fri Jun 07 15:32:46 BST 2024
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
