@@ -21,4 +21,4 @@ this.setContext();
 return this.writeFormType("animl");
 }, "JSV.common.JSViewer,JSV.common.ExportType,JU.OC,JSV.common.Spectrum,~N,~N,JSV.common.PanelData,~B");
 });
-;//5.0.1-v7 Wed Apr 02 04:50:42 CDT 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
