@@ -36,4 +36,4 @@ font.fontMetrics.font = font.font;
 return Math.ceil(font.fontMetrics.measureText(text).width);
 }}, "JU.Font,~S");
 })();
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
