@@ -31,7 +31,7 @@ this.LocContact = "";
 this.casName = "";
 this.sampleowner = "";
 this.obNucleus = "";
-this.StrObFreq = "";
+this.strObFreq = "";
 this.increasing = false;
 this.continuous = false;
 this.ivspoints = 0;
@@ -86,9 +86,10 @@ spectrum.setYFactor(this.yFactor);
 spectrum.setLongDate(this.LongDate);
 spectrum.setOrigin(this.origin);
 spectrum.setOwner(this.owner);
+spectrum.setNucleusAndFreq(this.obNucleus, true);
 JSV.source.JDXReader.addHeader(LDRTable, "##PATHLENGTH", this.pathlength);
 JSV.source.JDXReader.addHeader(LDRTable, "##RESOLUTION", this.resolution);
-if (!this.StrObFreq.equals("")) JSV.source.JDXReader.addHeader(LDRTable, "##.OBSERVEFREQUENCY", this.StrObFreq);
+if (!this.strObFreq.equals("")) JSV.source.JDXReader.addHeader(LDRTable, "##.OBSERVEFREQUENCY", this.strObFreq);
 if (!this.obNucleus.equals("")) JSV.source.JDXReader.addHeader(LDRTable, "##.OBSERVENUCLEUS", this.obNucleus);
 JSV.source.JDXReader.addHeader(LDRTable, "##$MANUFACTURER", this.vendor);
 if (!this.casRN.equals("")) JSV.source.JDXReader.addHeader(LDRTable, "##CASREGISTRYNO", this.casRN);
@@ -175,6 +176,6 @@ throw e;
 }
 }
 }, "~N,~B");
-c$.tagNames =  Clazz.newArray(-1, ["audittrail", "experimentstepset", "sampleset", "xx result", "spectrum", "metadatalist", "conditionlist", "parameterlist", "sample", "spectrumdata", "peaklist", "author", "peaklist"]);
+c$.tagNames =  Clazz.newArray(-1, ["audittrail", "experimentstepset", "sampleset", "xx result", "spectrum", "metadatalist", "conditionlist", "parameterlist", "sample", "spectrumdata", "peaklist", "author", "peaklist", "acquisitionnucleus", "effectiveexcitationfield", "spectrum1d", "spectrumAnnotationList", "chemicalcompound", "identifier", "npmrd_id", "structure", "atomlist", "atom", "bondlist", "bond", "atomassignmentlist", "multiplet", "atoms", "multiplicity", "peakList", "peak", "acquisition", "spectrumdataarray", "spectrumlist"]);
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
