@@ -507,4 +507,4 @@ System.out.println("draw id d" + i + " intersection unitcell hkl " + bp.hkl() +
 c$.ptInner = JU.P3.new3(NaN, 0, 0);
 c$.bzColors =  Clazz.newArray(-1, ["red", "green", "skyblue", "orange", "yellow", "blue", "violet"]);
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
