@@ -10,7 +10,7 @@ this.out = null;
 this.t8 = null;
 Clazz.instantialize(this, arguments);}, JU, "BinaryDocument", JU.BC, javajs.api.GenericBinaryDocument);
 Clazz.prepareFields (c$, function(){
-this.t8 =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/8, 0);
+this.t8 =  Clazz.newByteArray (8, 0);
 });
 Clazz.overrideMethod(c$, "close", 
 function(){
@@ -69,7 +69,7 @@ return b;
 });
 Clazz.overrideMethod(c$, "readBytes", 
 function(n){
-var b =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
+var b =  Clazz.newByteArray (n, 0);
 this.readByteArray(b, 0, n);
 return b;
 }, "~N");
@@ -100,7 +100,7 @@ return m;
 }, "~A,~N,~N");
 Clazz.overrideMethod(c$, "readString", 
 function(nChar){
-var temp =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.SimpleName*/nChar, 0);
+var temp =  Clazz.newByteArray (nChar, 0);
 var n = this.readByteArray(temp, 0, nChar);
 return  String.instantialize(temp, 0, n, "UTF-8");
 }, "~N");
@@ -197,7 +197,7 @@ offset -= this.nBytes;
 }if (this.out == null) {
 this.stream.skipBytes(offset);
 } else {
-this.readByteArray( Clazz.newByteArray (/*org.eclipse.jdt.core.dom.CastExpression*/offset, 0), 0, offset);
+this.readByteArray( Clazz.newByteArray (offset, 0), 0, offset);
 }this.nBytes += offset;
 } catch (e) {
 if (Clazz.exceptionOf(e,"java.io.IOException")){
@@ -223,4 +223,4 @@ function(b){
 this.isBigEndian = b;
 }, "~B");
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
