@@ -1,5 +1,5 @@
 Clazz.declarePackage("JU");
-Clazz.load(["javajs.api.GenericCifDataParser", "java.util.Hashtable", "JU.SB"], "JU.CifDataParser", ["JU.Lst", "$.PT"], function(){
+Clazz.load(["javajs.api.GenericCifDataParser", "java.util.Hashtable", "JU.SB"], "JU.CifDataParser", ["JU.Lst"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.reader = null;
 this.br = null;
@@ -9,7 +9,6 @@ this.ich = 0;
 this.cch = 0;
 this.wasUnquoted = false;
 this.cterm = '\0';
-this.nullString = "\0";
 this.asObject = false;
 this.debugging = false;
 this.strPeeked = null;
@@ -22,6 +21,7 @@ this.haveData = false;
 this.fileHeader = null;
 this.isHeader = true;
 this.skipToken = false;
+this.nTypesRemaining = 2147483647;
 Clazz.instantialize(this, arguments);}, JU, "CifDataParser", null, javajs.api.GenericCifDataParser);
 Clazz.prepareFields (c$, function(){
 this.columnData =  new Array(100);
@@ -36,7 +36,7 @@ return 1;
 });
 Clazz.defineMethod(c$, "setNullValue", 
 function(nullString){
-this.nullString = nullString;
+JU.CifDataParser.nullString = nullString;
 }, "~S");
 Clazz.overrideMethod(c$, "getColumnData", 
 function(i){
@@ -59,19 +59,23 @@ return this;
 }, "javajs.api.GenericLineReader,java.io.BufferedReader,~B");
 Clazz.overrideMethod(c$, "getFileHeader", 
 function(){
-return this.fileHeader.toString();
+return (this.fileHeader == null ? "" : this.fileHeader.toString());
 });
 Clazz.overrideMethod(c$, "getAllCifData", 
 function(){
 return this.getAllCifDataType([]);
 });
-Clazz.defineMethod(c$, "getAllCifDataType", 
+Clazz.overrideMethod(c$, "getAllCifDataType", 
 function(types){
 if (types != null) {
-if (types.length == 0) types = null;
- else for (var i = 0; i < types.length; i++) types[i] = this.fixKey(types[i]);
-
-}this.line = "";
+if (types.length == 0) {
+types = null;
+} else {
+for (var i = 0; i < types.length; i++) {
+types[i] = this.fixKey(types[i]);
+}
+}}this.nTypesRemaining = (types == null ? 2147483647 : types.length);
+this.line = "";
 var key;
 var data = null;
 var data0 = null;
@@ -79,7 +83,7 @@ var allData =  new java.util.Hashtable();
 var models =  new JU.Lst();
 allData.put("models", models);
 this.asObject = (this.getVersion() >= 2);
-this.nullString = null;
+JU.CifDataParser.nullString = null;
 var saveFrames =  new JU.Lst();
 try {
 while ((key = this.getNextToken()) != null) {
@@ -89,6 +93,7 @@ data.put("name", key);
 continue;
 }if (key.startsWith("loop_")) {
 this.getAllCifLoopData(data, types);
+if (this.nTypesRemaining == 0) break;
 continue;
 }if (key.startsWith("save_")) {
 if (key.equals("save_")) {
@@ -129,34 +134,16 @@ if (Clazz.exceptionOf(e, Exception)){
 throw e;
 }
 }
-this.nullString = "\0";
+JU.CifDataParser.nullString = "\0";
 return allData;
 }, "~A");
-Clazz.defineMethod(c$, "getAllCifLoopData", 
-function(data, types){
-var key;
-var keyWords =  new JU.Lst();
-var o;
-var skipping = false;
-while ((o = this.peekToken()) != null && (typeof(o)=='string') && (o).charAt(0) == '_') {
-key = this.fixKey(this.getTokenPeeked());
-keyWords.addLast(key);
-if (types == null || this.checkKey(types, key)) data.put(key,  new JU.Lst());
- else skipping = true;
-}
-this.columnCount = keyWords.size();
-if (this.columnCount == 0) return;
-this.isLoop = true;
-if (skipping) this.skipLoop(false);
- else while (this.getData()) for (var i = 0; i < this.columnCount; i++) (data.get(keyWords.get(i))).addLast(this.columnData[i]);
-
-
-this.isLoop = false;
-}, "java.util.Map,~A");
 Clazz.defineMethod(c$, "checkKey", 
 function(types, key){
-for (var i = 0; i < types.length; i++) if (key.startsWith(types[i])) return true;
-
+for (var i = 0; i < types.length; i++) {
+if (key.startsWith(types[i])) {
+if (key.equals(types[i])) this.nTypesRemaining--;
+return true;
+}}
 return false;
 }, "~A,~S");
 Clazz.overrideMethod(c$, "readLine", 
@@ -251,16 +238,6 @@ function(){
 this.ich = this.ichPeeked;
 return this.strPeeked;
 });
-Clazz.overrideMethod(c$, "fullTrim", 
-function(str){
-var pt0 = -1;
-var pt1 = str.length;
-while (++pt0 < pt1 && JU.PT.isWhitespace(str.charAt(pt0))) {
-}
-while (--pt1 > pt0 && JU.PT.isWhitespace(str.charAt(pt1))) {
-}
-return str.substring(pt0, pt1 + 1);
-}, "~S");
 Clazz.overrideMethod(c$, "toUnicode", 
 function(data){
 var pt;
@@ -328,7 +305,7 @@ this.haveData = (this.columnCount > 0);
 }}, "~A,~S,~S,~A,~A");
 Clazz.overrideMethod(c$, "fixKey", 
 function(key){
-return (key.startsWith("_magnetic") ? key.substring(9) : key.startsWith("_jana") ? key.substring(5) : key).$replace('.', '_').toLowerCase();
+return (key.charAt(1) == 'm' && key.startsWith("_magnetic") ? key.substring(9) : key.charAt(1) == 'j' && key.startsWith("_jana") ? key.substring(5) : key).$replace('.', '_').toLowerCase();
 }, "~S");
 Clazz.defineMethod(c$, "setString", 
 function(str){
@@ -381,7 +358,7 @@ return this.getQuotedStringOrObject(ch);
 this.wasUnquoted = true;
 while (this.ich < this.cch && !this.isTerminator(ch = this.str.charAt(this.ich))) ++this.ich;
 
-if (this.ich == ichStart + 1) if (this.nullString != null && (this.str.charAt(ichStart) == '.' || this.str.charAt(ichStart) == '?')) return this.nullString;
+if (this.ich == ichStart + 1) if (JU.CifDataParser.nullString != null && (this.str.charAt(ichStart) == '.' || this.str.charAt(ichStart) == '?')) return JU.CifDataParser.nullString;
 var s = this.str.substring(ichStart, this.ich);
 return this.unquoted(s);
 });
@@ -445,8 +422,8 @@ function(){
 this.ich++;
 var cterm0 = this.cterm;
 this.cterm = ']';
-var ns = this.nullString;
-this.nullString = null;
+var ns = JU.CifDataParser.nullString;
+JU.CifDataParser.nullString = null;
 var lst = (this.asObject ?  new JU.Lst() : null);
 var n = 0;
 var str = "";
@@ -460,7 +437,7 @@ if (n++ > 0) str += ",";
 str += value;
 }}
 this.cterm = cterm0;
-this.nullString = ns;
+JU.CifDataParser.nullString = ns;
 return (this.asObject ? lst : "[" + str + "]");
 });
 Clazz.overrideMethod(c$, "skipNextToken", 
@@ -470,6 +447,35 @@ this.getNextToken();
 this.skipToken = false;
 return "<skipped>";
 });
+Clazz.defineMethod(c$, "getAllCifLoopData", 
+function(data, types){
+var key;
+var keyWords =  new JU.Lst();
+var o;
+var havedata = (types == null);
+while ((o = this.peekToken()) != null && (typeof(o)=='string') && (o).charAt(0) == '_') {
+key = this.fixKey(this.getTokenPeeked());
+keyWords.addLast(key);
+if (types == null || this.checkKey(types, key)) {
+data.put(key,  new JU.Lst());
+havedata = true;
+}}
+var skipping = !havedata;
+this.columnCount = keyWords.size();
+if (this.columnCount == 0) return;
+this.isLoop = true;
+if (skipping) {
+this.skipLoop(false);
+} else {
+while (this.getData()) {
+for (var i = 0; i < this.columnCount; i++) {
+var cdata = data.get(keyWords.get(i));
+if (cdata != null) cdata.addLast(this.columnData[i]);
+}
+}
+}this.isLoop = false;
+}, "java.util.Map,~A");
+c$.nullString = "\0";
 c$.htFields =  new java.util.Hashtable();
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Sun May 18 17:30:59 CDT 2025
