@@ -12,9 +12,10 @@ function(){
 return this.reader.readLine();
 });
 c$.readCifData = Clazz.defineMethod(c$, "readCifData", 
-function(parser, br){
-return parser.set(null, br, false).getAllCifData();
-}, "javajs.api.GenericCifDataParser,java.io.BufferedReader");
+function(parser, br, keys){
+parser.set(null, br, false);
+return (keys == null ? parser.getAllCifData() : parser.getAllCifDataType(keys));
+}, "javajs.api.GenericCifDataParser,java.io.BufferedReader,~A");
 c$.fixUTF = Clazz.defineMethod(c$, "fixUTF", 
 function(bytes){
 var encoding = JU.Rdr.getUTFEncoding(bytes);
@@ -380,4 +381,4 @@ return this.stream;
 /*eoif3*/})();
 c$.b264 = null;
 });
-;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
+;//5.0.1-v7 Sun May 18 17:49:37 CDT 2025
