@@ -1,3 +1,3 @@
 Clazz.declarePackage("javajs.api.js");
 Clazz.declareInterface(javajs.api.js, "JSAppletObject");
-;//5.0.1-v7 Wed Apr 02 04:50:42 CDT 2025
+;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
